@@ -18,6 +18,7 @@ OC.L10N.register(
     "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Minimalus ištrintų kanalų ir aplankų saugojimo laikas po pašalinimo iš duomenų bazės; reikšmių, kurios mažesnės už 60 sekundžių, bus nepaisoma.",
     "Maximum read count per feed" : "Didžiausias kanalo straipsnių kiekis",
     "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off" : "Apibrėžia, kiek kanale gali būti perskaityta daugiausiai straipsnių, kurie nebus ištrinti išvalymo užduoties; jeigu seni straipsniai, juos perskaičius, vėl atsiranda, padidinkite šią reikšmę; neigiamos reikšmės, tokios kaip -1, išjungia šią ypatybę",
+    "Maximum redirects" : "Daugiausiai peradresavimų",
     "How many redirects the feed fetcher should follow" : "Kiek kartų kanalų gaviklis turėtų sekti paskui peradresavimus",
     "Maximum feed page size" : "Didžiausias kanalo puslapio dydis",
     "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Didžiausias kanalo dydis, baitais. Jei RSS/Atom straipsnio puslapis yra didesnis nei ši reikšmė, tuomet atnaujinimas bus nutrauktas",
@@ -91,6 +92,7 @@ OC.L10N.register(
     "Compact view" : "Rodyti tik antraštes",
     "Expand articles on key navigation" : "Rodyti pilnus straipsnius perjungiant klavišais",
     "Show all articles" : "Rodyti visus straipsnius",
+    "Reverse ordering (oldest on top)" : "Atvirkštinis rikiavimas (seniausi viršuje)",
     "Subscriptions (OPML)" : "Prenumeratos (OPML)",
     "Import" : "Importuoti",
     "Export" : "Eksportuoti",
