@@ -18,13 +18,14 @@ OC.L10N.register(
     "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Najkrajši čas, po katerem bodo viri in mape odstranjeni iz podatkovne zbirke. Vrednosti pod 60 sekundami so prezrte.",
     "Maximum read count per feed" : "Največje število prikazanih virov",
     "Maximum redirects" : "Največje število preusmeritev",
-    "How many redirects the feed fetcher should follow" : "Koliko preusmeritev naj bralnik virov sledi",
+    "How many redirects the feed fetcher should follow" : "Koliko preusmeritvam naj sledi bralnik virov",
     "Maximum feed page size" : "Največja velikost strani vira",
     "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Največja dovoljena velikost vira v bajtih. Če je vir RSS/ATOM večji od te vrednosti, bo posodobitev prekinjena.",
     "Feed fetcher timeout" : "Čas nalaganja vira",
-    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Čas, ki je namenjen za nalaganje virov RSS ali Atom. Po tem času je nalaganje virov prekinjeno.",
+    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Čas, namenjen nalaganju virov RSS in Atom. Po tem času je nalaganje virov prekinjeno.",
     "Explore Service URL" : "Razišči spletni naslov storitve",
     "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "Če je podan, bo prek tega naslova URL storitve potekala poizvedba za vire in njihov i zbor. Za preklop v vgrajeno storitev določevanja, mora biti polje prazno.",
+    "For more information check the wiki" : "Za več podrobnosti obiščite Wiki",
     "Saved" : "Shranjeno",
     "Download" : "Prejmi",
     "Close" : "Zapri",
@@ -38,7 +39,7 @@ OC.L10N.register(
     "Star article" : "Označi prispevek z zvezdico",
     "Unstar article" : "Odstrani zvezdico s prispevka",
     "Keep article unread" : "Obdrži kot neprebrano",
-    "Remove keep article unread" : "Odstrani možnost neprebrano",
+    "Remove keep article unread" : "Odstrani možnost ohranjanja prispevkov neprebranih",
     "by" : "od",
     "from" : "od",
     "Play audio" : "Predvajaj zvok",
@@ -62,7 +63,7 @@ OC.L10N.register(
     "Load previous folder" : "Naloži predhodno mapo",
     "Scroll to active navigation entry" : "Pomakni se na predmet v žarišču",
     "Focus search field" : "Postavi iskalno polje v žarišče",
-    "Mark current article's feed/folder read" : "Označi trenutni predmet kot prebran",
+    "Mark current article's feed/folder read" : "Označi trenutni vir kot prebran",
     "Ajax or webcron mode detected! Your feeds will not be updated!" : "Zaznan je način Ajax oziroma webcron! Izbrani viri ne bodo posodobljeni!",
     "How to set up the operating system cron" : "Kako nastaviti opravila cron operacijskega sistema",
     "Install and set up a faster parallel updater that uses the News app's update API" : "Namesti in nastavi hitrejši vzporedni posodabljalnik, ki za posodobitev uporablja  API programa  News",
@@ -75,7 +76,7 @@ OC.L10N.register(
     "Go back" : "Nazaj",
     "Folder exists already!" : "Mapa že obstaja!",
     "Credentials" : "Poverila",
-    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Basic Auth podatki morajo biti shranjeni nekodirani! Vsakdo z dostopom do baze jih lahko vidi!",
+    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Osnovni overitveni podatki HTTP Auth morajo biti shranjeni nekodirani! Vsakdo z dostopom do podatkovne zbirke bo imel omogočen dostop!",
     "Username" : "Uporabniško ime",
     "Password" : "Geslo",
     "New Folder" : "Nova mapa",
@@ -96,6 +97,7 @@ OC.L10N.register(
     "Disable full text" : "Omogoči polno besedilo",
     "Unread updated" : "Neprebrano je posodobljeno",
     "Ignore updated" : "Prezri posodobljeno",
+    "Open feed URL" : "Odpri naslov URL vira",
     "Delete" : "Izbriši",
     "Dismiss" : "Opusti",
     "Collapse" : "Skrči",
@@ -113,6 +115,7 @@ OC.L10N.register(
     "Subscriptions (OPML)" : "Naročnine (OPML)",
     "Import" : "Uvozi",
     "Export" : "Izvozi",
+    "Error when importing: File does not contain valid OPML" : "Napaka med uvažanjem: datoteka ne vsebuje veljavnega zapisa OPML",
     "Error when importing: OPML is does neither contain feeds nor folders" : "Napaka med uvažanjem: datoteka OPML ne vsebuje niti virov niti map",
     "Unread/Starred Articles" : "Neprebrani/Označeni prispevki",
     "Error when importing: file does not contain valid JSON" : "Napaka uvoza: datoteka ne vsebuje veljavnih podatkov JSON.",
